analphipy.NoroFrenkelPair
=========================

.. currentmodule:: analphipy

.. autoclass:: NoroFrenkelPair

   
   ..
      .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree:
   
      ~NoroFrenkelPair.B2
      ~NoroFrenkelPair.B2_dbeta
      ~NoroFrenkelPair.B2_sw
      ~NoroFrenkelPair.__init__
      ~NoroFrenkelPair.eps
      ~NoroFrenkelPair.from_phi
      ~NoroFrenkelPair.from_phi_class
      ~NoroFrenkelPair.lam
      ~NoroFrenkelPair.lam_dbeta
      ~NoroFrenkelPair.phi_rep
      ~NoroFrenkelPair.secondvirial
      ~NoroFrenkelPair.secondvirial_dbeta
      ~NoroFrenkelPair.secondvirial_sw
      ~NoroFrenkelPair.sig
      ~NoroFrenkelPair.sig_dbeta
      ~NoroFrenkelPair.sw_dict
      ~NoroFrenkelPair.table
   
   

   
   
   

   
   
   .. rubric:: Dunder Methods

   .. autosummary::
      :toctree:
   
      ~NoroFrenkelPair.__repr__
   
   